Package: rym
Type: Package
Title: R Interface to Yandex Metrica API
Version: 1.1.2
Authors@R: 
    c(person(given  = "Alexey",
             family = "Seleznev",
             role   = c("aut", "cre"),
             email  = "selesnow@gmail.com",
             comment = c(ORCID = "0000-0003-0410-7385")),
      person(given = "Netpeak",
             role = c("cph")))
Maintainer: Alexey Seleznev <selesnow@gmail.com>
Description: Allows work with 'Management API' for load counters, segments, filters,
	user permissions and goals list from Yandex Metrica, 'Reporting API' allows you to get 
	information about the statistics of site visits and other data without
	using the web interface, 'Logs API' allows to receive non-aggregated data and 
	'Compatible with Google Analytics Core Reporting API v3' allows 
	receive information about site traffic and other data using field names 
	from Google Analytics Core API.	For more information see official 
	documents <https://yandex.ru/dev/metrika/doc/api2/concept/about-docpage>.
Depends: R (>= 3.5.0)
BugReports: https://github.com/selesnow/rym/issues
Suggests: knitr, rmarkdown
VignetteBuilder: knitr
License: GPL-2
Imports: httr, httr2, stringr, utils, purrr
URL: https://selesnow.github.io/rym/
Encoding: UTF-8
Language: ru
NeedsCompilation: no
Packaged: 2026-05-20 07:04:59 UTC; User
Author: Alexey Seleznev [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-0410-7385>),
  Netpeak [cph]
Repository: CRAN
Date/Publication: 2026-05-20 08:10:02 UTC
Built: R 4.6.0; ; 2026-05-22 00:20:10 UTC; unix
