export(rym_auth)
export(rym_get_counters)
export(rym_get_data)
export(rym_get_ga)
export(rym_get_goals)
export(rym_get_logs)
export(rym_get_filters)
export(rym_get_direct_clients)
export(rym_get_segments)
export(rym_get_my_logins)
export(rym_add_goal)
export(rym_add_segment)
export(rym_users_grants)
export(rym_upload_expense)
export(rym_delete_uploaded_expense)
export(rym_get_uploadings_expense)
export(rym_upload_calls)
export(rym_enable_calls)
export(rym_disable_calls)
export(rym_allow_calls)
export(rym_get_uploadings_calls)
export(rym_upload_offline_conversion)
export(rym_enable_offline_conversion)
export(rym_disable_offline_conversion)
export(rym_allow_offline_conversion)
export(rym_get_uploadings_offline_conversions)
import(httr2)
importFrom(httr2, request, req_body_form, req_perform, req_url_query, req_headers, resp_body_json)
importFrom(httr, GET)
importFrom(httr, POST)
importFrom(httr, DELETE)
importFrom(httr, content)
importFrom(httr, stop_for_status)
importFrom(httr, add_headers)
importFrom(httr, upload_file)
importFrom(stringr, str_glue)
importFrom(purrr, map_df, flatten)
importFrom(utils, browseURL, read.delim, URLencode, write.csv)
S3method(print, RymToken)