---
title: "rym: Загрузка информации о звонках в Яндекс.Метрику"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{rym: Загрузка информации о звонках в Яндекс.Метрику}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  eval = FALSE,
  comment = "#>"
)
```

Начиная с версии `rym 1.0.0` у вас появилась загружать в Яндекс.Метрику информацию о звонках. Для этого в пакет были добавлены 5 функций.

* `rym_enable_calls()` - Включить учёт звонков
* `rym_disable_calls()` - Выключить учёт звонков
* `rym_allow_calls()` - Возвращает дату и время, начиная с которого звонки могут быть привязаны к визитам для указанного счетчика.
* `rym_upload_calls()` - Загрузка информации о звонках в Яндекс.Метрику
* `rym_get_uploadings_calls()` - Возвращает список загрузок звонков


## Подготовка Яндекс.Метрики к загрузке оффлайн конверсий
Для того, что бы вы могли начать загрузку информации о звонках вам необходимо выполнить несколько действий.

### Проверка готовности Метрики к загрузке конверсий
Учтенный Метрикой визит может быть дополнен информацией о конверсии в течение 21 дня. Период учета конверсий увеличивается постепенно с момента включения опции.

Включить опцию можно либо в интерфейсе Метрики (На странице Настройка → Загрузка данных), либо с помощью функции `rym_enable_calls()`.

Чтобы проверить, можно ли загружать данные и за какой период, используйте функцию `rym_allow_calls()`.

```{r eval=FALSE}
# оффлайн конверсии
rym_enable_calls(123456789, 
                 login = 'yandex_login') 

# проверка можно ли загружать данные и за какой период
rym_allow_calls(123456789, 
                login = 'yandex_login')
```

При необходимости вы можете отключить опцию загрузки оффлайн конверсий функцией `rym_disable_calls()`.

### Подготовка данных для загрузки в Яндекс.Метрику
Перед загрузкой данных по оффлайн конверсиям в Яндекс.Метрику, вам необходимо привести их к нужному формату.

Датафрейм должен содержать следующие столбцы:

#### Обязательные поля
* UserId | ClientId | Yclid - Идентификатор посетителя сайта или рекламной кампании в Директе *(пример: 12345)*.

#### Необязательные поля
* StaticCall - является ли звонок статическим (1 — статический, 0 — динамический).
* Price - цена цели, десятичным разделителем является точка (.).
* Currency -  валюта в трехбуквенном формате ISO 4217.
* PhoneNumber - номер телефона без пробелов (с указанием кода страны и города). Например, +70123456789.
* TalkDuration - длительность звонка в секундах.
* HoldDuration - длительность ожидания звонка в секундах.
* CallMissed - пропущен ли звонок (1 — пропущенный, 0 — отвеченный).
* Tag - произвольная метка. Может использоваться для отметки качества звонка или его итоге и т. д. Например, «клиента не устроила цена».
* FirstTimeCaller - первичность (1 — первичный звонок, 0 — вторичный звонок).
* URL - URL, с которого был звонок (ассоциированная с событием страница). Например, это может быть лэндинг для рекламной кампании, на котором указан номер телефона (PhoneNumber).
* CallTrackerURL - URL перехода в интерфейс колл-трекера.

## Загрузка информации о звонках в Яндекс Метрику
Теперь вы можете использовать функцию `rym_upload_calls()` для загрузки оффлайн конверсий в Яндекс.Метрику.

```{r eval=FALSE}
rym_upload_calls(12345, 
                 data = conv_data,
                 client.id.type = "CLIENT_ID",
                 login = 'yandex_login')
```

Обработка данных может занимать до 24 часов, после чего загруженные данные появятся в отчётах Яндекс.Метрики.

## Получить список загрузок информации о звонках
Посмотреть список загрузок, и их статусы можно с помощью функции `rym_get_uploadings_calls()`.

```{r eval=FALSE}

uploads <- rym_get_uploadings_calls(
              counter = 123456789,
              login   = 'yandex_login')
```

## Ссылки
* [Передача данных о звонках](https://yandex.ru/dev/metrika/doc/api2/practice/calls-docpage/)
* [Загрузка информации о звонках](https://yandex.ru/dev/metrika/doc/api2/management/offline_conversion/uploadcalls-docpage/)
* [Как отслеживать звонки в метрике](https://yandex.ru/support/metrica/data/calls.html)