---
title: "rym: Загрузка данных о расходах в Яндекс Метрику"
author: "Alexey Seleznev"
date: "`r Sys.Date()`"
output: rmarkdown::html_vignette
vignette: >
  %\VignetteIndexEntry{rym: Загрузка данных о расходах в Яндекс Метрику}
  %\VignetteEngine{knitr::rmarkdown}
  %\VignetteEncoding{UTF-8}
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

Начиная с версии `rym 0.7.0` в пакет были добавлены 3 функции для управления загрузкой данных о расходах на рекламу в Яндекс.Метрике.

* `rym_upload_expense()` - Загрузка расходов в Яндекс.Метрику
* `rym_delete_uploaded_expense()` - Удаление данных о расходах из Яндекс.Метрики
* `rym_get_uploadings_expense()` - Список загрузок расходов

## Аргументы которые присутвуют в функциях:

* counter - номер счётчика в который необходимо загрузить данные
* data - data.frame, содержащий данные о расходах на рекламу которые требуется загрузить в Яндекс.Метрику
* comment - комментарий к загрузке (не обязательно)
* login - ваш лошин в яндексе
* token.path - путь к папке в которой хранятся учётные данные

## Формат данных для загрузки
data.frame содержащий данные о расходах должен иметь следующую структуру:

### Обязательные поля

* Date — строка, дата в формате YYYY-MM-DD или диапазон дат в формате YYYY-MM-DD/YYYY-MM-DD.
* UTMSource — строка, значение метки utm_source.
* Expenses — число, сумма, которая была потрачена на рекламу без учета НДС. Десятичным разделителем является точка.

### Необязательные поля:

* UTMMedium — строка, значение метки utm_medium.
* UTMCampaign — строка, значение метки utm_campaign.
* UTMTerm — строка, значение метки utm_term.
* UTMContent — строка, значение метки utm_content.
* Currency — строка, трехбуквенный код валюты по ISO 4217.
* Clicks — число, количество кликов по рекламным объявлениям.

## Пример подготовки, загрузки и удаленния данных

```{r, eval=FALSE}
# данные для загрузки
expense <- data.frame(Date        = c("2020-06-01",
                                      "2020-06-02"),
                      UTMSource   = c("test_s_1",
                                      "test_s_2"),
                      Expenses    = c(88.12,
                                      92.11),
                      UTMMedium   = c("cpc",
                                      "cpm"),
                      UTMCampaign = c("camp1",
                                      "camp2"),
                      UTMTerm     = c("term1",
                                      "term2"),
                      UTMContent  = c("cont1",
                                      "cont2"),
                      Currency    = c("RUB", 
                                      "RUB"),
                      Clicks      = c(11, 15))

# отправка данных в Яндекс.Метрику
rym_upload_expense(counter = 11111, 
                   data    = expense,
                   login   = 'yandex_login', 
                   token.path = "D:/packlab/rym")

# Удаление данных из Яндекс.Метрики
rym_delete_uploaded_expense(counter = 11111, 
                            data    = expense,
                            login   = 'yandex_login', 
                            token.path = "D:/packlab/rym")

# получение списка загрузок
loaded <- rym_get_uploadings_expense(counter = 11111, 
                                     login   = 'yandex_login', 
                                     token.path = "D:/packlab/rym")

```

## Как найти загруженные данные в интерфейсе Яндекс.Метрики
Отправленные данные можно найти в отчёте "Источники, расходы и ROI"

Где найти отчёт:
![Отчёт в интерфейсе метрики](http://img.netpeak.ua/alsey/159189561657_kiss_38kb.png)

Отчёт:
![Отчёт](http://img.netpeak.ua/alsey/159189557849_kiss_77kb.png)

## Ссылки

* [Документация к API методам](https://yandex.ru/dev/metrika/doc/api2/management/expenses/uploadbody-docpage/)
* [Об учёте расходов на рекламу](https://yandex.ru/support/metrica/ad/expenses.html#expences)